@@ -21,8 +21,6 @@ function startFarabi(editorId) {
 		});
 
 		editor.setOption("theme", theme);
-
-		humane.log("Mode changed to " + $selectedTheme.html());
 	});
 
 	function displayHelp(cm) {
@@ -43,7 +41,6 @@ function startFarabi(editorId) {
 	function _displayHelp(topic, bShowDialog) {
 		$.post('/help_search', {"topic": topic}, function(results) {
 			if(results.length > 0) {
-				humane.log("Found " + results.length + " help results for '" + topic +"'!");
 				$(".topic").val(topic);
 				var html = '';
 				for(var i = 0; i < results.length; i++) {
@@ -57,8 +54,6 @@ function startFarabi(editorId) {
 						$(".preview").html(results[index].html);
 					}).change().show();
 			} else {
-				humane.log("No help found for '" + topic + "'");
-
 				$(".topic").val(topic);
 				$(".results").html('').hide();
 				$(".preview").html('<span class="text-error">No results found!</span>');
@@ -106,7 +101,6 @@ function startFarabi(editorId) {
 
 	$("#mode_selector").change(function() {
 		var $selectedMode = $(":selected", this);
-		humane.log("Mode changed to " + $selectedMode.html());
 		var mode = $selectedMode.val();
 		if(mode == 'clike') {
 			changeMode(editor, mode, 'text/x-csrc');
@@ -142,8 +136,8 @@ function startFarabi(editorId) {
 	// Hook up with cursor activity event
 	editor.on("cursorActivity", function(cm) {
 			// Highlight active line
-			cm.setLineClass(hlLine, null, null);
-			hlLine = cm.setLineClass(cm.getCursor().line, null, "activeline");
+			cm.removeLineClass(hlLine, "background", "activeline");
+			hlLine = cm.addLineClass(cm.getCursor().line, "background", "activeline");
 
 			// Highlight selection matches
 			cm.matchHighlight("CodeMirror-matchhighlight");
@@ -174,6 +168,9 @@ function startFarabi(editorId) {
 		// Show editor stats at startup
 		showEditorStats(editor);
 
+		// Trigger theme selection
+		$("#theme_selector").change();
+
 		// Update POD tab at startup
 		podChanged(editor);
 
@@ -185,20 +182,18 @@ function startFarabi(editorId) {
 	}, 0);
 
 	// Highlight active line
-	var hlLine = editor.setLineClass(0, "activeline");
+	var hlLine = editor.addLineClass(0, "background", "activeline");
 
 	$(".results").hide();
 
 	$(".run_in_browser_button").click(function() {
 		// Load Perlito - Perl 5 to JS Compiler
-		humane.log("Loading Perlito 5");
 		$.ajax({
 			url: 'assets/perlito/perlito5.min.js',
 			dataType: "script",
 			cache: true,
 			success: function() {
-				runOnPerlito(editor.getValue());
-				humane.log("Run in browser finished");
+				runOnPerlito5(editor.getValue());
 			}
 		});
 	});
@@ -209,10 +204,8 @@ function startFarabi(editorId) {
 		$.post('/perl_tidy', {"source": editor.getValue()}, function(data) {
 			if(data.error == '') {
 				editor.setValue(data.source);
-				humane.log("Your code is tidied!");
 			} else {
 				$output.val('Error:\n' + data.error);
-				humane.log("Perl::Tidy failed! Please check output");
 			}
 		});
 	});
@@ -222,18 +215,13 @@ function startFarabi(editorId) {
 			var $output = $('#output');
 			$output.val('');
 			
-			// Handle exit code
-			if (data.exit > 0) {
-				humane.log("Exit code: " + data.exit);
-			}
-			
 			// Handle STDERR
 			if (data.stderr.length) {
 				$output.val(data.stderr + "\n");
 			}
 			
 			// Handle STDOUT
-			$output.val($output.val() + data.stdout);
+			$output.val($output.val() + data.stdout + "\nExit code: " + data.exit);
 			
 			// Show output tab
 			$('a[href="#output-tab"]').tab('show');
@@ -330,18 +318,18 @@ function startFarabi(editorId) {
 
 	$('.about_button').click(function() {
 		if(typeof p5pkg == 'undefined') {
-			humane.log("Loading Perlito 5");
 			$.ajax({
 				url: 'assets/perlito/perlito5.min.js',
 				dataType: "script",
 				cache: true,
 				success: function() {
-					$('#perlito-version').html(  p5pkg[ "main" ][ "v_]"]);
-					humane.log("Perlito 5 loaded");
+					$('#perlito5-version').html(  p5pkg[ "main" ][ "v_]"]);
+					//$('#perlito6-version').html( p6pkg[ "main" ][ "v_]"]);
 				}
 			});
 		} else {
 			$('#perlito-version').html(p5pkg[ "main" ][ "v_]" ]);
+			//$('#perlito6-version').html( p6pkg[ "main" ][ "v_]"]);
 		}
 		$('#jquery-version').html($().jquery);
 		$('#codemirror-version').html(CodeMirror.version);
@@ -401,7 +389,7 @@ function startFarabi(editorId) {
 	});
 }
 
-function runOnPerlito(source) {
+function runOnPerlito5(source) {
 
 	var $output = $('#output');
 
